.. swyft documentation master file, created by
   sphinx-quickstart on Thu Nov 12 11:23:08 2020.
   You can adapt this file completely to your liking, but it should at least
   contain the root `toctree` directive.

.. warning::
   *swyft* is research software under heavy development and still in its alpha
   phase.  There are many rough edges, and things might break.  However, the
   core algorithms work, and we use *swyft* in production for research papers.
   If you encounter problems, please contact the authors or submit a bug
   report.

Welcome to swyft's documentation!
=================================

.. centered::
   **Neural nested marginal posterior estimation**

*Cursed by the dimensionality of your nuisance space? Wasted by Markov
chains that reject your simulations? Exhausted from messing with
simplistic models, because your inference algorithm cannot handle the
truth? Try swyft for some pain relief.*

The latest version of *swyft* can be found on `github <https://github.com/undark-lab/swyft>`_.

On google colab we put a `quickstart guide <https://colab.research.google.com/github/undark-lab/swyft/blob/master/notebooks/Quickstart.ipynb>`_,
and a `tutorial <https://colab.research.google.com/github/undark-lab/swyft/blob/master/notebooks/Tutorial.ipynb>`_.


.. toctree::
   :maxdepth: 2
   :caption: Contents:

   goals
   context
   install
   quickstart
   theorytex
   autodoc


Indices and tables
==================

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`
